@@ -1,7 +1,7 @@
 /*
  * GSysInfo Applet
  *  - A GNOME panel applet to display various system information.
- *  Copyright (C) 1999 Jason D. Hildebrand
+ *  Copyright (C) 2000 Jason D. Hildebrand
  *  - jdhildeb@undergrad.math.uwaterloo.ca
  *  - http://www.undergrad.math.uwaterloo.ca/~jdhildeb/gsysinfo
  *
@@ -38,9 +38,14 @@
 #include "properties.h"
 #include "sysinfo.h"
 
+#if defined( DEBUG )
+FILE * debugfile;
+#define DEBUG_FILENAME "/tmp/gsysinfo_debug"
+#endif
+
 a_color AppColors[NUM_COLORS] = {
     // colors for load average bar
-    { "loadavgbar0", "#FFC1C1", 0 },	// RosyBrown1
+    { "loadavgbar0", "#FFA0A0", 0 },	// RosyBrown1
     { "loadavgbar1", "#FF6A6A", 0 },	// IndianRed1
     { "loadavgbar2", "#FF4500", 0 },	// OrangeRed1
     { "loadavgbar3", "#FF3838", 0 },	// firebrick1
@@ -79,6 +84,14 @@ main (int argc, char ** argv)
   bindtextdomain (PACKAGE, GNOMELOCALEDIR);
   textdomain (PACKAGE);
 
+  #if defined( DEBUG )
+  debugfile = fopen( DEBUG_FILENAME, "w" );
+  if( debugfile == NULL ) {
+    perror( DEBUG_FILENAME );
+    return 1;
+  }
+  #endif
+
   applet_widget_init ("gsysinfo_applet", VERSION, argc, argv, NULL, 0, NULL);
 
   applet_factory_new ("gsysinfo_applet", NULL,
@@ -103,6 +116,10 @@ main (int argc, char ** argv)
 
   applet_widget_gtk_main ();
 
+  #if defined( DEBUG )
+  fclose( debugfile );
+  #endif
+
   return 0;
 } /* main */
 
@@ -228,11 +245,14 @@ void draw_mem( GSysInfoData * gd, int barx, int bary, int bar_breadth, int bar_d
 }
 
 void draw_swap( GSysInfoData * gd, int barx, int bary, int bar_breadth, int bar_depth ) {
-    int totalspace = 0;
-    int totalfree = 0;
-    int totalused;
+    unsigned long totalspace = 0;
+    unsigned long totalfree = 0;
+    unsigned long totalused;
     int n;
     int segsize;
+    #if defined( DEBUG )
+    char buff[ 255 ];
+    #endif
     
     for( n = 0; n < gd->numswapfiles ; n++ ) {
 	totalspace += gd->memstats[ n + 1 ].total;
@@ -545,7 +565,7 @@ about_cb (AppletWidget *widget, gpointer data)
 
   gd->about_box =
     gnome_about_new (_("GSysInfo Applet"), VERSION,
-		     _("Copyright (C) 1999 Jason D. Hildebrand"),
+		     _("Copyright (C) 2000 Jason D. Hildebrand"),
 		     (const char **) authors,
 	     _("This applet displays the system load average, "
 	       "current CPU usage, memory usage, and swap file usage, in the "
@@ -559,13 +579,14 @@ about_cb (AppletWidget *widget, gpointer data)
 	       "filled in.\n"
 
 	       " \nCPU USAGE:\n"
-	       "The CPU usage gauge is divided into user time, system time, and nice time "
-	       "(in that order).  The types of usage are distinguished by colour.\n"
+	       "The CPU usage gauge has up to three sections.  White (empty) represents "
+	       "idle time. Light blue represents user time, medium blue represents system "
+	       "time, and dark blue represents time used by 'nice' processes.\n"
 
 	       " \nMEMORY USAGE:\n"
 
-	       "The memory gauge has two sections: normal memory, and memory used for "
-	       "cache and buffers.\n"
+	       "The memory gauge has two sections: normal memory use (light green), and "
+	       "memory used for cache and buffers (dark green).\n"
 
 	       " \nSWAP USAGE:\n"
 
